@@ -1,4 +1,7 @@
 import os
+import json
+from pathlib import Path
+import copy
 
 import pytest
 import requests_mock
@@ -47,14 +50,14 @@ JSON_WORKFLOW_TASKS = {
     "data": [
         {
             "id": "aa2cba17-d35c-4395-ab01-a0fd8191a4b3",
-            "name": "sobloo-s2-l1c-aoiclipped:1",
+            "name": "esa-s2-l2a-gtiff-visual:1",
             "parentsIds": [],
-            "blockName": "sobloo-s2-l1c-aoiclipped",
-            "blockVersionTag": "2.3.0",
+            "blockName": "esa-s2-l2a-gtiff-visual",
+            "blockVersionTag": "1.0.1",
             "block": {
-                "id": "3a381e6b-acb7-4cec-ae65-50798ce80e64",
-                "name": "sobloo-s2-l1c-aoiclipped",
-                "displayName": "Sentinel-2 L1C MSI AOI clipped",
+                "id": "c4cb8913-2ef3-4e82-a426-65ea8faacd9a",
+                "name": "esa-s2-l2a-gtiff-visual",
+                "displayName": "Sentinel-2 L2A Visual (GeoTIFF)",
                 "parameters": {
                     "ids": {"type": "array", "default": "None"},
                     "bbox": {"type": "array", "default": "None"},
@@ -65,7 +68,7 @@ JSON_WORKFLOW_TASKS = {
                 },
                 "type": "DATA",
                 "isDryRunSupported": True,
-                "version": "2.3.0",
+                "version": "1.0.1",
             },
             "environment": "None",
         },
@@ -108,16 +111,19 @@ JSON_BLOCKS = {
             "id": "4ed70368-d4e1-4462-bef6-14e768049471",
             "name": "tiling",
             "displayName": "Raster Tiling",
+            "type": "PROCESSING",
         },
         {
             "id": "c0d04ec3-98d7-4183-902f-5bcb2a176d89",
             "name": "sharpening",
             "displayName": "Sharpening Filter",
+            "type": "PROCESSING",
         },
         {
-            "id": "a2daaab4-196d-4226-a018-a810444dcad1",
-            "name": "sobloo-s2-l1c-aoiclipped",
-            "displayName": "Sentinel-2 L1C MSI AOI clipped",
+            "id": "c4cb8913-2ef3-4e82-a426-65ea8faacd9a",
+            "name": "esa-s2-l2a-gtiff-visual",
+            "displayName": "Sentinel-2 L2A Visual (GeoTIFF)",
+            "type": "DATA",
         },
     ],
     "error": {},
@@ -125,24 +131,24 @@ JSON_BLOCKS = {
 
 JSON_WORKFLOW_ESTIMATION = {
     "data": {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "blockConsumption": {
-                "resources": {"unit": "MEGABYTE", "min": 3.145728, "max": 3.145728},
-                "credit": {"min": 0, "max": 0},
+                "credit": {"max": 0, "min": 0},
+                "resources": {"max": 0, "min": 0, "unit": "SQUARE_KM"},
             },
             "machineConsumption": {
-                "duration": {"min": 4041, "max": 26380},
-                "credit": {"min": 3, "max": 3},
+                "credit": {"max": 1, "min": 1},
+                "duration": {"max": 0, "min": 0},
             },
         },
         "tiling:1": {
             "blockConsumption": {
-                "resources": {"unit": "MEGABYTE", "min": 3.145728, "max": 3.145728},
-                "credit": {"min": 0, "max": 0},
+                "credit": {"max": 0, "min": 0},
+                "resources": {"max": 3.145728, "min": 3.145728, "unit": "MEGABYTE"},
             },
             "machineConsumption": {
-                "duration": {"min": 80930, "max": 428927},
-                "credit": {"min": 2, "max": 9},
+                "credit": {"max": 9, "min": 2},
+                "duration": {"max": 428927, "min": 80930},
             },
         },
     },
@@ -208,39 +214,16 @@ JSON_ORDER = {
 JSON_ORDERS = {"data": {"orders": [JSON_ORDER["data"]]}, "error": None}
 
 
-# TODO: Use patch.dict instead of 2 fictures?
-@pytest.fixture()
-def auth_mock_no_request(requests_mock):
-    auth = Auth(
-        project_id=PROJECT_ID,
-        project_api_key=PROJECT_APIKEY,
-        authenticate=False,
-        retry=False,
-        get_info=False,
-    )
-
-    url_get_token = (
-        f"https://{auth.project_id}:{auth.project_api_key}@api.up42."
-        f"{auth.env}/oauth/token"
-    )
-    json_get_token = {"data": {"accessToken": TOKEN}}
-    requests_mock.post(
-        url=url_get_token,
-        json=json_get_token,
-    )
-
-    return auth
-
-
 @pytest.fixture()
 def auth_mock(requests_mock):
     # token for initial authentication
-    url_get_token = f"https://{PROJECT_ID}:{PROJECT_APIKEY}@api.up42.com/oauth/token"
-    json_get_token = {"data": {"accessToken": TOKEN}}
-    requests_mock.post(
-        url=url_get_token,
-        json=json_get_token,
-    )
+    url_get_token = "https://api.up42.com/oauth/token"
+    json_get_token = {
+        "data": {"accessToken": TOKEN},
+        "access_token": TOKEN,
+        "token_type": "bearer",
+    }
+    requests_mock.post(url_get_token, json=json_get_token)
 
     url_get_workspace = f"https://api.up42.com/projects/{PROJECT_ID}"
     json_get_workspace = {"data": {"workspaceId": WORKSPACE_ID}}
@@ -253,7 +236,6 @@ def auth_mock(requests_mock):
         project_api_key=PROJECT_APIKEY,
         authenticate=True,
         retry=False,
-        get_info=True,
     )
 
     # get_blocks
@@ -293,7 +275,7 @@ def project_mock(auth_mock, requests_mock):
 
     project = Project(auth=auth_mock, project_id=auth_mock.project_id)
 
-    # create_workflow. If with use_existing=True, requires workflow info mock.
+    # create_workflow.
     url_create_workflow = (
         f"{project.auth._endpoint()}/projects/" f"{project.project_id}/workflows/"
     )
@@ -303,6 +285,20 @@ def project_mock(auth_mock, requests_mock):
     }
     requests_mock.post(url=url_create_workflow, json=json_create_workflow)
 
+    # workflow.info (for create_workflow)
+    url_workflow_info = (
+        f"{project.auth._endpoint()}/projects/"
+        f"{project.project_id}/workflows/{WORKFLOW_ID}"
+    )
+    json_workflow_info = {
+        "data": {
+            "name": WORKFLOW_NAME,
+            "description": WORKFLOW_DESCRIPTION,
+        },
+        "error": {},
+    }
+    requests_mock.get(url=url_workflow_info, json=json_workflow_info)
+
     # get_workflows
     url_get_workflows = (
         f"{project.auth._endpoint()}/projects/" f"{project.project_id}/workflows"
@@ -335,14 +331,34 @@ def project_mock(auth_mock, requests_mock):
     )
     json_project_settings = {
         "data": [
-            {"name": "MAX_CONCURRENT_JOBS"},
-            {"name": "MAX_AOI_SIZE"},
-            {"name": "JOB_QUERY_LIMIT_PARAMETER_MAX_VALUE"},
+            {"name": "MAX_CONCURRENT_JOBS", "value": "10"},
+            {"name": "MAX_AOI_SIZE", "value": "5000"},
+            {"name": "JOB_QUERY_LIMIT_PARAMETER_MAX_VALUE", "value": "20"},
         ],
         "error": {},
     }
     requests_mock.get(url=url_project_settings, json=json_project_settings)
 
+    # project settings update
+    url_projects_settings_update = (
+        f"{project.auth._endpoint()}/projects/project_id_123/settings"
+    )
+    json_desired_project_settings = {
+        "data": [
+            {"name": "MAX_CONCURRENT_JOBS", "value": "500"},
+            {"name": "MAX_AOI_SIZE", "value": "5"},
+            {"name": "JOB_QUERY_LIMIT_PARAMETER_MAX_VALUE", "value": "20"},
+        ],
+        "error": {},
+    }
+    requests_mock.post(
+        url_projects_settings_update,
+        [
+            {"status_code": 404, "json": json_desired_project_settings},
+            {"status_code": 201, "json": json_desired_project_settings},
+        ],
+    )
+
     return project
 
 
@@ -352,6 +368,50 @@ def project_live(auth_live):
     return project
 
 
+@pytest.fixture()
+def workflow_mock_empty(auth_mock, requests_mock):
+    """
+    Only to test error handling of functions that don't correctly work on workflows
+    without tasks (blocks). For the fully mocked workflow see workflow_mock fixture.
+    """
+    # info
+    url_workflow_info = (
+        f"{auth_mock._endpoint()}/projects/"
+        f"{auth_mock.project_id}/workflows/"
+        f"{WORKFLOW_ID}"
+    )
+    json_workflow_info = {
+        "data": {
+            "name": WORKFLOW_NAME,
+            "id": WORKFLOW_ID,
+            "description": PROJECT_DESCRIPTION,
+            "createdAt": "some_date",
+            "xyz": 789,
+        },
+        "error": {},
+    }
+    requests_mock.get(url=url_workflow_info, json=json_workflow_info)
+
+    workflow = Workflow(
+        auth=auth_mock,
+        workflow_id=WORKFLOW_ID,
+        project_id=auth_mock.project_id,
+    )
+
+    # get_workflow_tasks
+    json_empty_workflow_tasks = {
+        "error": "None",
+        "data": [],
+    }
+    url_workflow_tasks = (
+        f"{workflow.auth._endpoint()}/projects/{workflow.auth.project_id}/workflows/"
+        f"{workflow.workflow_id}/tasks"
+    )
+    requests_mock.get(url=url_workflow_tasks, json=json_empty_workflow_tasks)
+
+    return workflow
+
+
 @pytest.fixture()
 def workflow_mock(auth_mock, requests_mock):
     # info
@@ -566,7 +626,7 @@ def jobs_live(auth_live):
 @pytest.fixture()
 def estimation_mock(auth_mock):
     input_parameters = {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "time": "2018-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
             "limit": 1,
             "bbox": [13.33409, 52.474922, 13.38547, 52.500398],
@@ -576,14 +636,14 @@ def estimation_mock(auth_mock):
 
     input_tasks = [
         {
-            "name": "sobloo-s2-l1c-aoiclipped:1",
+            "name": "esa-s2-l2a-gtiff-visual:1",
             "parentName": None,
-            "blockId": "3a381e6b-acb7-4cec-ae65-50798ce80e64",
-            "blockVersionTag": "2.3.0",
+            "blockId": "c4cb8913-2ef3-4e82-a426-65ea8faacd9a",
+            "blockVersionTag": "1.0.1",
         },
         {
             "name": "tiling:1",
-            "parentName": "sobloo-s2-l1c-aoiclipped:1",
+            "parentName": "esa-s2-l2a-gtiff-visual:1",
             "blockId": "3e146dd6-2b67-4d6e-a422-bb3d973e32ff",
             "blockVersionTag": "2.2.3",
         },
@@ -595,7 +655,7 @@ def estimation_mock(auth_mock):
 @pytest.fixture()
 def estimation_live(auth_live):
     input_parameters = {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "time": "2018-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
             "limit": 1,
             "bbox": [13.33409, 52.474922, 13.38547, 52.500398],
@@ -605,14 +665,14 @@ def estimation_live(auth_live):
 
     input_tasks = [
         {
-            "name": "sobloo-s2-l1c-aoiclipped:1",
+            "name": "esa-s2-l2a-gtiff-visual:1",
             "parentName": None,
-            "blockId": "3a381e6b-acb7-4cec-ae65-50798ce80e64",
-            "blockVersionTag": "2.3.0",
+            "blockId": "c4cb8913-2ef3-4e82-a426-65ea8faacd9a",
+            "blockVersionTag": "1.0.1",
         },
         {
             "name": "tiling:1",
-            "parentName": "sobloo-s2-l1c-aoiclipped:1",
+            "parentName": "esa-s2-l2a-gtiff-visual:1",
             "blockId": "3e146dd6-2b67-4d6e-a422-bb3d973e32ff",
             "blockVersionTag": "2.2.3",
         },
@@ -679,12 +739,14 @@ def jobtask_mock(auth_mock, requests_mock):
     )
 
     # get_results_json
-    url = (
+    url_results_json = (
         f"{jobtask.auth._endpoint()}/projects/{jobtask.auth.project_id}/"
         f"jobs/{jobtask.job_id}/tasks/{jobtask.jobtask_id}/"
         f"outputs/data-json/"
     )
-    requests_mock.get(url, json={"type": "FeatureCollection", "features": []})
+    requests_mock.get(
+        url_results_json, json={"type": "FeatureCollection", "features": []}
+    )
 
     # get_download_url
     url_download_result = (
@@ -783,7 +845,6 @@ def asset_live(auth_live):
 
 @pytest.fixture()
 def order_mock(auth_mock, requests_mock):
-
     # order info
     url_order_info = (
         f"{auth_mock._endpoint()}/workspaces/{auth_mock.workspace_id}/orders/{ORDER_ID}"
@@ -828,7 +889,17 @@ def tools_live(auth_live):
 
 
 @pytest.fixture()
-def catalog_mock(auth_mock):
+def catalog_mock(auth_mock, requests_mock):
+    with open(
+        Path(__file__).resolve().parent / "mock_data/search_response.json"
+    ) as json_file:
+        json_search_response = json.load(json_file)
+    url_search = f"{auth_mock._endpoint()}/catalog/stac/search"
+    requests_mock.post(
+        url=url_search,
+        json=json_search_response,
+    )
+
     return Catalog(auth=auth_mock)
 
 
@@ -837,6 +908,59 @@ def catalog_live(auth_live):
     return Catalog(auth=auth_live)
 
 
+@pytest.fixture()
+def catalog_pagination_mock(auth_mock, requests_mock):
+    with open(
+        Path(__file__).resolve().parent / "mock_data/search_response.json"
+    ) as json_file:
+        search_response_json = json.load(json_file)
+    search_response_json["features"] = search_response_json["features"] * 500
+
+    pagination_response_json = copy.deepcopy(search_response_json)
+    pagination_response_json["features"] = pagination_response_json["features"][:50]
+    pagination_response_json["links"][1] = pagination_response_json["links"][
+        0
+    ]  # indicator of pagination exhaustion (after first page)
+
+    url_search = f"{auth_mock._endpoint()}/catalog/stac/search"
+    requests_mock.post(
+        url_search,
+        [{"json": search_response_json}, {"json": pagination_response_json}],
+    )
+
+    return Catalog(auth=auth_mock)
+
+
+@pytest.fixture()
+def catalog_usagetype_mock(auth_mock, requests_mock):
+    with open(
+        Path(__file__).resolve().parent / "mock_data/search_response.json"
+    ) as json_file:
+        search_response_json = json.load(
+            json_file
+        )  # original response is usagetype data
+
+    response_analytics = copy.deepcopy(search_response_json)
+    response_analytics["features"][0]["properties"]["up42:usageType"] = ["ANALYTICS"]
+    response_data_and_analytics = copy.deepcopy(search_response_json)
+    response_data_and_analytics["features"][0]["properties"]["up42:usageType"] = [
+        "DATA",
+        "ANALYTICS",
+    ]
+
+    url_search = f"{auth_mock._endpoint()}/catalog/stac/search"
+    requests_mock.post(
+        url_search,
+        [
+            {"json": search_response_json},
+            {"json": response_analytics},
+            {"json": response_data_and_analytics},
+        ],
+    )
+
+    return Catalog(auth=auth_mock)
+
+
 @pytest.fixture()
 def project_mock_max_concurrent_jobs(project_mock):
     def _project_mock_max_concurrent_jobs(maximum=5):
