@@ -1,12 +1,22 @@
 import os
 from pathlib import Path
+import json
+import time
 import tempfile
 
 import pytest
 
+
 # pylint: disable=unused-import
 from .context import Job, JobTask
-from .fixtures import auth_mock, auth_live, job_mock, job_live, jobtask_mock
+from .fixtures import (
+    auth_mock,
+    auth_live,
+    job_mock,
+    job_live,
+    jobtask_mock,
+    workflow_live,
+)
 from .fixtures import DOWNLOAD_URL, JOBTASK_ID
 
 
@@ -82,7 +92,7 @@ def test_track_status_fail(job_mock, status, requests_mock):
 
 
 def test_cancel_job(job_mock, requests_mock):
-    url = f"{job_mock.auth._endpoint()}/jobs/{job_mock.job_id}/cancel/"
+    url = f"{job_mock.auth._endpoint()}/projects/{job_mock.project_id}/jobs/{job_mock.job_id}/cancel/"
     requests_mock.post(url, status_code=200)
     job_mock.cancel_job()
 
@@ -131,10 +141,11 @@ def test_get_jobtasks_result_json(job_mock):
 
 def test_job_download_result(job_mock, requests_mock):
     out_tgz = Path(__file__).resolve().parent / "mock_data/result_tif.tgz"
-    out_tgz_file = open(out_tgz, "rb")
+    with open(out_tgz, "rb") as src_tgz:
+        out_tgz_file = src_tgz.read()
     requests_mock.get(
         url=DOWNLOAD_URL,
-        content=out_tgz_file.read(),
+        content=out_tgz_file,
         headers={"x-goog-stored-content-length": "163"},
     )
 
@@ -160,10 +171,11 @@ def test_job_download_result(job_mock, requests_mock):
 def test_job_download_result_nounpacking(job_mock, requests_mock):
 
     out_tgz = Path(__file__).resolve().parent / "mock_data/result_tif.tgz"
-    out_tgz_file = open(out_tgz, "rb")
+    with open(out_tgz, "rb") as src_tgz:
+        out_tgz_file = src_tgz.read()
     requests_mock.get(
         url=DOWNLOAD_URL,
-        content=out_tgz_file.read(),
+        content=out_tgz_file,
         headers={"x-goog-stored-content-length": "163"},
     )
 
@@ -174,6 +186,30 @@ def test_job_download_result_nounpacking(job_mock, requests_mock):
         assert len(out_files) == 1
 
 
+@pytest.mark.skip(reason="Sometimes takes quite long to cancel the job on the server.")
+@pytest.mark.live
+def test_cancel_job_live(workflow_live):
+    input_parameters_json = (
+        Path(__file__).resolve().parent / "mock_data/input_params_simple.json"
+    )
+    jb = workflow_live.test_job(
+        input_parameters=input_parameters_json, track_status=False
+    )
+    # Can happen that the test job is finished before the cancellation kicks in server-side.
+    jb.cancel_job()
+
+    # Give service time to cancel job before assertions
+    time.sleep(3)
+    assert jb.status in ["CANCELLED", "CANCELLING"]
+
+    assert isinstance(jb, Job)
+    with open(input_parameters_json) as src:
+        job_info_params = json.load(src)
+        job_info_params.update({"config": {"mode": "DRY_RUN"}})
+        assert jb._info["inputs"] == job_info_params
+        assert jb._info["mode"] == "DRY_RUN"
+
+
 @pytest.mark.live
 def test_job_download_result_live(job_live):
     with tempfile.TemporaryDirectory() as tempdir:
@@ -212,7 +248,7 @@ def test_job_download_result_dimap_live(auth_live):
         assert Path(out_files[0]).exists()
         assert Path(out_files[20]).exists()
         assert Path(out_files[-1]).exists()
-        assert Path(out_files[-1]).name == "data.json"
+        assert "data.json" in [Path(of).name for of in out_files]
         assert len(out_files) == 54
 
 
