@@ -10,6 +10,7 @@ from .context import Workflow, Job, JobCollection, Asset
 from .fixtures import (
     auth_mock,
     auth_live,
+    workflow_mock_empty,
     workflow_mock,
     workflow_live,
     job_mock,
@@ -40,34 +41,11 @@ def test_get_workflow_tasks_normal_and_basic(workflow_mock):
     tasks = workflow_mock.get_workflow_tasks(basic=False)
 
     assert len(tasks) == 2
-    assert tasks[0] == {
-        "id": "aa2cba17-d35c-4395-ab01-a0fd8191a4b3",
-        "name": "sobloo-s2-l1c-aoiclipped:1",
-        "parentsIds": [],
-        "blockName": "sobloo-s2-l1c-aoiclipped",
-        "blockVersionTag": "2.3.0",
-        "block": {
-            "id": "3a381e6b-acb7-4cec-ae65-50798ce80e64",
-            "name": "sobloo-s2-l1c-aoiclipped",
-            "displayName": "Sentinel-2 L1C MSI AOI clipped",
-            "parameters": {
-                "ids": {"type": "array", "default": "None"},
-                "bbox": {"type": "array", "default": "None"},
-                "time": {
-                    "type": "dateRange",
-                    "default": "2018-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
-                },
-            },
-            "type": "DATA",
-            "isDryRunSupported": True,
-            "version": "2.3.0",
-        },
-        "environment": "None",
-    }
+    assert tasks[0] == JSON_WORKFLOW_TASKS["data"][0]
 
     tasks = workflow_mock.get_workflow_tasks(basic=True)
     assert len(tasks) == 2
-    assert tasks["sobloo-s2-l1c-aoiclipped:1"] == "2.3.0"
+    assert tasks["esa-s2-l2a-gtiff-visual:1"] == "1.0.1"
     assert tasks["tiling:1"] == "2.2.3"
 
 
@@ -75,7 +53,7 @@ def test_get_workflow_tasks_normal_and_basic(workflow_mock):
 def test_get_workflow_tasks_live(workflow_live):
     workflow_tasks = workflow_live.get_workflow_tasks(basic=True)
     assert isinstance(workflow_tasks, dict)
-    assert "sobloo-s2-l1c-aoiclipped:1" in list(workflow_tasks.keys())
+    assert "esa-s2-l2a-gtiff-visual:1" in list(workflow_tasks.keys())
 
 
 def test_get_compatible_blocks(workflow_mock):
@@ -91,6 +69,13 @@ def test_get_compatible_blocks_live(workflow_live):
     assert "tiling" in list(compatible_blocks.keys())
 
 
+def test_get_compatible_blocks_empty_workflow_returns_data_blocks(workflow_mock_empty):
+    compatible_blocks = workflow_mock_empty.get_compatible_blocks()
+    assert isinstance(compatible_blocks, dict)
+    assert len(compatible_blocks) == 1
+    assert "esa-s2-l2a-gtiff-visual" in list(compatible_blocks.keys())
+
+
 def test_construct_full_workflow_tasks_dict_unkwown_block_raises(workflow_mock):
     input_tasks = ["some_block"]
     with pytest.raises(ValueError):
@@ -101,20 +86,20 @@ def test_construct_full_workflow_tasks_dict_unkwown_block_raises(workflow_mock):
     "input_tasks",
     [
         [
-            "a2daaab4-196d-4226-a018-a810444dcad1",
+            "c4cb8913-2ef3-4e82-a426-65ea8faacd9a",
             "4ed70368-d4e1-4462-bef6-14e768049471",
         ],
-        ["sobloo-s2-l1c-aoiclipped", "tiling"],
+        ["esa-s2-l2a-gtiff-visual", "tiling"],
         [
-            "Sentinel-2 L1C MSI AOI clipped",
+            "Sentinel-2 L2A Visual (GeoTIFF)",
             "Raster Tiling",
         ],
         [
-            "a2daaab4-196d-4226-a018-a810444dcad1",
+            "c4cb8913-2ef3-4e82-a426-65ea8faacd9a",
             "tiling",
         ],
         [
-            "Sentinel-2 L1C MSI AOI clipped",
+            "Sentinel-2 L2A Visual (GeoTIFF)",
             "4ed70368-d4e1-4462-bef6-14e768049471",
         ],
     ],
@@ -124,10 +109,10 @@ def test_construct_full_workflow_tasks_dict(workflow_mock, input_tasks):
         input_tasks=input_tasks
     )
     assert isinstance(full_workflow_tasks_dict, list)
-    assert full_workflow_tasks_dict[0]["name"] == "sobloo-s2-l1c-aoiclipped:1"
+    assert full_workflow_tasks_dict[0]["name"] == "esa-s2-l2a-gtiff-visual:1"
     assert full_workflow_tasks_dict[0]["parentName"] is None
     assert full_workflow_tasks_dict[1]["name"] == "tiling:1"
-    assert full_workflow_tasks_dict[1]["parentName"] == "sobloo-s2-l1c-aoiclipped:1"
+    assert full_workflow_tasks_dict[1]["parentName"] == "esa-s2-l2a-gtiff-visual:1"
     assert (
         full_workflow_tasks_dict[1]["blockId"] == "4ed70368-d4e1-4462-bef6-14e768049471"
     )
@@ -136,13 +121,13 @@ def test_construct_full_workflow_tasks_dict(workflow_mock, input_tasks):
 def test_add_workflow_tasks_full(workflow_mock, requests_mock):
     input_tasks_full = [
         {
-            "name": "sobloo-s2-l1c-aoiclipped:1",
+            "name": "esa-s2-l2a-gtiff-visual:1",
             "parentName": None,
             "blockId": "a2daaab4-196d-4226-a018-a810444dcad1",
         },
         {
             "name": "sharpening:1",
-            "parentName": "sobloo-s2-l1c-aoiclipped",
+            "parentName": "esa-s2-l2a-gtiff-visual",
             "blockId": "4ed70368-d4e1-4462-bef6-14e768049471",
         },
     ]
@@ -168,7 +153,7 @@ def test_get_parameter_info(workflow_mock):
     assert isinstance(parameter_info, dict)
     assert all(
         x in list(parameter_info.keys())
-        for x in ["tiling:1", "sobloo-s2-l1c-aoiclipped:1"]
+        for x in ["tiling:1", "esa-s2-l2a-gtiff-visual:1"]
     )
     assert all(
         x in list(parameter_info["tiling:1"].keys()) for x in ["nodata", "tile_width"]
@@ -181,7 +166,7 @@ def test_get_parameter_info_live(workflow_live):
     assert isinstance(parameter_info, dict)
     assert all(
         x in list(parameter_info.keys())
-        for x in ["tiling:1", "sobloo-s2-l1c-aoiclipped:1"]
+        for x in ["tiling:1", "esa-s2-l2a-gtiff-visual:1"]
     )
     assert all(
         x in list(parameter_info["tiling:1"].keys())
@@ -195,36 +180,16 @@ def test_get_default_parameters(workflow_mock):
     assert isinstance(default_parameters, dict)
     assert all(
         x in list(default_parameters.keys())
-        for x in ["tiling:1", "sobloo-s2-l1c-aoiclipped:1"]
+        for x in ["tiling:1", "esa-s2-l2a-gtiff-visual:1"]
     )
     assert default_parameters["tiling:1"] == {"nodata": "None", "tile_width": 768}
-    assert default_parameters["sobloo-s2-l1c-aoiclipped:1"] == {
+    assert default_parameters["esa-s2-l2a-gtiff-visual:1"] == {
         "ids": "None",
         "bbox": "None",
         "time": "2018-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
     }
 
 
-def test_construct_parameters(workflow_mock):
-    parameters = workflow_mock.construct_parameters(
-        geometry=shapely.geometry.point.Point(1, 3),
-        geometry_operation="bbox",
-        start_date="2014-01-01",
-        end_date="2016-12-31",
-        limit=1,
-    )
-    assert isinstance(parameters, dict)
-    assert parameters == {
-        "sobloo-s2-l1c-aoiclipped:1": {
-            "ids": "None",
-            "bbox": [0.99999, 2.99999, 1.00001, 3.00001],
-            "time": "2014-01-01T00:00:00Z/2016-12-31T23:59:59Z",
-            "limit": 1,
-        },
-        "tiling:1": {"nodata": "None", "tile_width": 768},
-    }
-
-
 def test_construct_parameters_scene_ids(workflow_mock):
     parameters = workflow_mock.construct_parameters(
         geometry=shapely.geometry.point.Point(1, 3),
@@ -233,7 +198,7 @@ def test_construct_parameters_scene_ids(workflow_mock):
     )
     assert isinstance(parameters, dict)
     assert parameters == {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "ids": ["s2_123223"],
             "bbox": [0.99999, 2.99999, 1.00001, 3.00001],
             "limit": 1,
@@ -242,13 +207,13 @@ def test_construct_parameters_scene_ids(workflow_mock):
     }
 
 
-def test_construct_parameter_only_ids(workflow_mock):
+def test_construct_parameter_scene_ids_without_geometry(workflow_mock):
     parameters = workflow_mock.construct_parameters(
         scene_ids=["s2_123223"],
     )
     assert isinstance(parameters, dict)
     assert parameters == {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "ids": ["s2_123223"],
             "bbox": "None",
             "limit": 1,
@@ -257,27 +222,18 @@ def test_construct_parameter_only_ids(workflow_mock):
     }
 
 
-def test_construct_parameter_order_ids(workflow_mock):
-    parameters = workflow_mock.construct_parameters(order_ids=["8472712912"])
-    assert isinstance(parameters, dict)
-    assert parameters == {
-        "sobloo-s2-l1c-aoiclipped:1": {"order_ids": ["8472712912"]},
-        "tiling:1": {"nodata": "None", "tile_width": 768},
-    }
-
-
 def test_construct_parameter_assets(workflow_mock, asset_mock, monkeypatch):
     parameters = workflow_mock.construct_parameters(assets=[asset_mock])
     assert isinstance(parameters, dict)
     assert parameters == {
-        "sobloo-s2-l1c-aoiclipped:1": {"asset_ids": [asset_mock.asset_id]},
+        "esa-s2-l2a-gtiff-visual:1": {"asset_ids": [asset_mock.asset_id]},
         "tiling:1": {"nodata": "None", "tile_width": 768},
     }
 
     parameters = workflow_mock.construct_parameters(assets=[asset_mock, asset_mock])
     assert isinstance(parameters, dict)
     assert parameters == {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "asset_ids": [asset_mock.asset_id, asset_mock.asset_id]
         },
         "tiling:1": {"nodata": "None", "tile_width": 768},
@@ -300,7 +256,7 @@ def test_construct_parameters_parallel(workflow_mock):
     assert isinstance(parameters_list, list)
     assert len(parameters_list) == 2
     assert parameters_list[0] == {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "ids": "None",
             "bbox": [0.99999, 2.99999, 1.00001, 3.00001],
             "time": "2014-01-01T00:00:00Z/2016-12-31T23:59:59Z",
@@ -321,7 +277,7 @@ def test_construct_parameters_parallel_multiple_intervals(workflow_mock):
     )
     assert len(parameters_list) == 4
     assert parameters_list[0] == {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "ids": "None",
             "bbox": [0.99999, 2.99999, 1.00001, 3.00001],
             "time": "2014-01-01T00:00:00Z/2016-12-31T23:59:59Z",
@@ -340,14 +296,14 @@ def test_construct_parameters_parallel_scene_ids(workflow_mock):
     )
     assert len(parameters_list) == 2
     assert parameters_list[0] == {
-        "sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "bbox": "None", "limit": 1},
+        "esa-s2-l2a-gtiff-visual:1": {"ids": ["S2abc"], "bbox": "None", "limit": 1},
         "tiling:1": {"nodata": "None", "tile_width": 768},
     }
 
 
 def test_estimate_jobs(workflow_mock, auth_mock, requests_mock):
     input_parameters = {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "time": "2018-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
             "limit": 1,
             "bbox": [13.33409, 52.474922, 13.38547, 52.500398],
@@ -372,16 +328,16 @@ def test_estimate_jobs(workflow_mock, auth_mock, requests_mock):
 @pytest.mark.live
 def test_estimate_jobs_live(workflow_live):
     input_parameters = {
-        "sobloo-s2-l1c-aoiclipped:1": {
+        "esa-s2-l2a-gtiff-visual:1": {
             "time": "2018-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
             "limit": 1,
             "bbox": [13.33409, 52.474922, 13.38547, 52.500398],
         },
-        "tiling:1": {"tile_width": 768},
+        "tiling:1": {"tile_width": 768, "tile_height": 768},
     }
     estimation = workflow_live.estimate_job(input_parameters)
 
-    assert estimation == JSON_WORKFLOW_ESTIMATION["data"]
+    assert estimation.keys() == JSON_WORKFLOW_ESTIMATION["data"].keys()
 
 
 def test_run_job(workflow_mock, job_mock, requests_mock):
@@ -405,8 +361,8 @@ def test_helper_run_parallel_jobs_dry_run(
 ):
     # pylint: disable=dangerous-default-value
     input_parameters_list = [
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1}},
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2def"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2abc"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2def"], "limit": 1}},
     ]
 
     example_response = {
@@ -443,8 +399,8 @@ def test_helper_run_parallel_jobs_all_fails(
 ):
     # pylint: disable=dangerous-default-value
     input_parameters_list = [
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1}},
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2def"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2abc"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2def"], "limit": 1}},
     ]
 
     response_failed = {
@@ -490,8 +446,8 @@ def test_helper_run_parallel_jobs_one_fails(
     workflow_mock, project_mock_max_concurrent_jobs
 ):
     input_parameters_list = [
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1}},
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2def"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2abc"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2def"], "limit": 1}},
     ]
 
     responses = [
@@ -547,8 +503,8 @@ def test_helper_run_parallel_jobs_default(
     """Takes 100sec."""
     # pylint: disable=dangerous-default-value
     input_parameters_list = [
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1}},
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2def"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2abc"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2def"], "limit": 1}},
     ] * 10
     example_response = {
         "error": None,
@@ -583,8 +539,8 @@ def test_helper_run_parallel_jobs_fail_concurrent_jobs(
 ):
     # pylint: disable=dangerous-default-value
     input_parameters_list = [
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2abc"], "limit": 1}},
-        {"sobloo-s2-l1c-aoiclipped:1": {"ids": ["S2def"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2abc"], "limit": 1}},
+        {"esa-s2-l2a-gtiff-visual:1": {"ids": ["S2def"], "limit": 1}},
     ] * 10
     example_response = {
         "error": None,
@@ -615,16 +571,16 @@ def test_helper_run_parallel_jobs_fail_concurrent_jobs(
 def test_test_jobs_parallel_live(workflow_live):
     input_parameters_list = [
         {
-            "sobloo-s2-l1c-aoiclipped:1": {
-                "time": "2019-01-01T00:00:00Z/2020-12-31T23:59:59Z",
+            "esa-s2-l2a-gtiff-visual:1": {
+                "time": "2019-01-01T00:00:00+00:00/2019-12-31T23:59:59+00:00",
                 "limit": 1,
                 "bbox": [13.375966, 52.515068, 13.378314, 52.516639],
             },
             "tiling:1": {"tile_width": 768, "tile_height": 768},
         },
         {
-            "sobloo-s2-l1c-aoiclipped:1": {
-                "time": "2019-12-01T00:00:00Z/2020-12-31T23:59:59Z",
+            "esa-s2-l2a-gtiff-visual:1": {
+                "time": "2020-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
                 "limit": 1,
                 "bbox": [13.375966, 52.515068, 13.378314, 52.516639],
             },
@@ -648,16 +604,16 @@ def test_test_jobs_parallel_live(workflow_live):
 def test_run_jobs_parallel_live(workflow_live):
     input_parameters_list = [
         {
-            "sobloo-s2-l1c-aoiclipped:1": {
-                "time": "2019-01-01T00:00:00Z/2020-12-31T23:59:59Z",
+            "esa-s2-l2a-gtiff-visual:1": {
+                "time": "2019-01-01T00:00:00+00:00/2019-12-31T23:59:59+00:00",
                 "limit": 1,
                 "bbox": [13.375966, 52.515068, 13.378314, 52.516639],
             },
             "tiling:1": {"tile_width": 768, "tile_height": 768},
         },
         {
-            "sobloo-s2-l1c-aoiclipped:1": {
-                "time": "2019-12-01T00:00:00Z/2020-12-31T23:59:59Z",
+            "esa-s2-l2a-gtiff-visual:1": {
+                "time": "2020-01-01T00:00:00+00:00/2020-12-31T23:59:59+00:00",
                 "limit": 1,
                 "bbox": [13.375966, 52.515068, 13.378314, 52.516639],
             },
@@ -732,7 +688,7 @@ def test_get_jobs_live(workflow_live):
     assert isinstance(jobcollection, list)
     assert isinstance(jobcollection.jobs[0], Job)
     assert all(
-        [j._info["workflowId"] == workflow_live.workflow_id for j in jobcollection.jobs]
+        j._info["workflowId"] == workflow_live.workflow_id for j in jobcollection.jobs
     )
 
 
