@@ -1,9 +1,8 @@
 from pathlib import Path
 
-from typing import Dict, List, Union
+from typing import List, Union
 
 from up42.auth import Auth
-from up42.tools import Tools
 from up42.utils import (
     get_logger,
     download_results_from_gcs,
@@ -13,7 +12,7 @@ from up42.utils import (
 logger = get_logger(__name__)
 
 
-class Asset(Tools):
+class Asset:
     """
     The Asset class enables access to the UP42 assets in the storage. Assets are results
     of orders or results of jobs with download blocks.
@@ -32,9 +31,7 @@ class Asset(Tools):
         self.auth = auth
         self.workspace_id = auth.workspace_id
         self.asset_id = asset_id
-        self.results = None
-        if self.auth.get_info:
-            self._info = self.info
+        self.results: Union[List[str], None] = None
 
     def __repr__(self):
         info = self.info
@@ -45,17 +42,16 @@ class Asset(Tools):
         )
 
     @property
-    def info(self) -> Dict:
+    def info(self) -> dict:
         """
         Gets the asset metadata information.
         """
         url = f"{self.auth._endpoint()}/workspaces/{self.workspace_id}/assets/{self.asset_id}"
         response_json = self.auth._request(request_type="GET", url=url)
-        self._info = response_json["data"]
         return response_json["data"]
 
     @property
-    def source(self) -> Dict:
+    def source(self) -> dict:
         """
         Gets the source of the Asset. One of `TASKING`, `ORDER`, `BLOCK`, `UPLOAD`.
         """
