@@ -3,20 +3,23 @@ Catalog search functionality
 """
 
 from pathlib import Path
-from typing import Dict, Union, List, Tuple
+from typing import Union, List, Tuple
 
 from pandas import Series
 from geopandas import GeoDataFrame
-from shapely.geometry import shape
 from shapely.geometry import Point, Polygon
 from geojson import Feature, FeatureCollection
 from tqdm import tqdm
 
 from up42.auth import Auth
-from up42.tools import Tools
 from up42.viztools import VizTools
 from up42.order import Order
-from up42.utils import get_logger, any_vector_to_fc, fc_to_query_geometry
+from up42.utils import (
+    get_logger,
+    any_vector_to_fc,
+    fc_to_query_geometry,
+    format_time_period,
+)
 
 logger = get_logger(__name__)
 
@@ -63,7 +66,7 @@ supported_sensors = {
 }
 
 # pylint: disable=duplicate-code
-class Catalog(VizTools, Tools):
+class Catalog(VizTools):
     """
     The Catalog class enables access to the UP42 catalog search. You can search
     for satellite image scenes (for different sensors and criteria like cloud cover),
@@ -86,10 +89,10 @@ class Catalog(VizTools, Tools):
     @staticmethod
     def construct_parameters(
         geometry: Union[
-            Dict,
+            dict,
             Feature,
             FeatureCollection,
-            List,
+            list,
             GeoDataFrame,
             Point,
             Polygon,
@@ -104,21 +107,27 @@ class Catalog(VizTools, Tools):
             "sentinel3",
             "sentinel5p",
         ],
+        usage_type: List[str] = ["DATA", "ANALYTICS"],
         limit: int = 10,
         max_cloudcover: float = 100,
         sortby: str = "acquisitionDate",
         ascending: bool = True,
-    ) -> Dict:
+    ) -> dict:
         """
         Follows STAC principles and property names.
 
         Args:
-            geometry: The search geometry, one of Dict, Feature, FeatureCollection,
-                List, GeoDataFrame, Point, Polygon.
+            geometry: The search geometry, one of dict, Feature, FeatureCollection,
+                list, GeoDataFrame, Point, Polygon.
             start_date: Query period starting day, format "2020-01-01".
             end_date: Query period ending day, format "2020-01-01".
             sensors: The satellite sensors to search for, one or multiple of
                 ["pleiades", "spot", "sentinel1", "sentinel2", "sentinel3", "sentinel5p"]
+            usage_type: Filter for imagery that can just be purchased & downloaded or also
+                processes. ["DATA"] (can only be download), ["ANALYTICS"] (can be downloaded
+                or used directly with a processing algorithm), ["DATA", "ANALYTICS"]
+                (can be any combination). The filter is inclusive, using ["DATA"] can
+                also result in results with ["DATA", "ANALYTICS"].
             limit: The maximum number of search results to return (1-max.500).
             max_cloudcover: Maximum cloudcover % - e.g. 100 will return all scenes,
                 8.4 will return all scenes with 8.4 or less cloudcover.
@@ -130,7 +139,8 @@ class Catalog(VizTools, Tools):
         Returns:
             The constructed parameters dictionary.
         """
-        datetime = f"{start_date}T00:00:00Z/{end_date}T23:59:59Z"
+        time_period = format_time_period(start_date=start_date, end_date=end_date)
+
         block_filters: List[str] = []
         for sensor in sensors:
             if sensor not in list(supported_sensors.keys()):
@@ -155,17 +165,27 @@ class Catalog(VizTools, Tools):
             query_filters["cloudCoverage"] = {"lte": max_cloudcover}  # type: ignore
 
         search_parameters = {
-            "datetime": datetime,
+            "datetime": time_period,
             "intersects": aoi_geometry,
             "limit": limit,
             "query": query_filters,
             "sortby": [{"field": f"properties.{sortby}", "direction": sort_order}],
         }
+
+        if usage_type == ["DATA"]:
+            search_parameters["query"]["up42:usageType"] = {"in": ["DATA"]}
+        elif usage_type == ["ANALYTICS"]:
+            search_parameters["query"]["up42:usageType"] = {"in": ["ANALYTICS"]}
+        elif usage_type == ["DATA", "ANALYTICS"]:
+            search_parameters["query"]["up42:usageType"] = {"in": ["DATA", "ANALYTICS"]}
+        else:
+            raise ValueError("Select correct `usage_type`")
+
         return search_parameters
 
     def search(
-        self, search_parameters: Dict, as_dataframe: bool = True
-    ) -> Union[GeoDataFrame, Dict]:
+        self, search_parameters: dict, as_dataframe: bool = True
+    ) -> Union[GeoDataFrame, dict]:
         """
         Searches the catalog for the the search parameters and returns the metadata of
         the matching scenes.
@@ -192,27 +212,34 @@ class Catalog(VizTools, Tools):
             ```
         """
         logger.info(f"Searching catalog with search_parameters: {search_parameters}")
+
+        # The API request would fail with a limit above 500, thus 500 is forced in the initial
+        # request but additional results are handled below via pagination.
+        max_limit = search_parameters["limit"]
+        if max_limit > 500:
+            search_parameters = dict(search_parameters)
+            search_parameters["limit"] = 500
+
         url = f"{self.auth._endpoint()}/catalog/stac/search"
-        response_json = self.auth._request("POST", url, search_parameters)
-        logger.info(f"{len(response_json['features'])} results returned.")
-        dst_crs = "EPSG:4326"
-        df = GeoDataFrame.from_features(response_json, crs=dst_crs)
-        if df.empty:
-            if as_dataframe:
-                return df
-            else:
-                return df.__geo_interface__
+        response_json: dict = self.auth._request("POST", url, search_parameters)
+        features = response_json["features"]
 
-        # Filter to actual geometries intersecting the aoi (Sobloo search uses a rectangular
-        # bounds geometry, can contain scenes that touch the aoi bbox, but not the aoi.
-        # So number returned images not consistent with set limit.
-        # TODO: Resolve on backend
-        geometry = search_parameters["intersects"]
-        poly = shape(geometry)
-        df = df[df.intersects(poly)]
-        df = df.reset_index(drop=True)
-        df.crs = dst_crs  # apply resets the crs
+        # Search results with more than 500 items are given as 50-per-page additional pages.
+        while len(features) < max_limit:
+            page_url = response_json["links"][0]["href"]
+            next_page_url = response_json["links"][1]["href"]
+            pagination_exhausted = next_page_url == page_url
+            if pagination_exhausted:
+                break
+            response_json = self.auth._request("POST", next_page_url)
+            features += response_json["features"]
 
+        features = features[:max_limit]
+        df = GeoDataFrame.from_features(
+            FeatureCollection(features=features), crs="EPSG:4326"
+        )
+
+        logger.info(f"{df.shape[0]} results returned.")
         if as_dataframe:
             return df
         else:
@@ -222,7 +249,7 @@ class Catalog(VizTools, Tools):
         self,
         image_ids: List[str],
         sensor: str,
-        output_directory: Union[str, Path] = None,
+        output_directory: Union[str, Path, None] = None,
     ) -> List[str]:
         """
         Gets the quicklooks of scenes from a single sensor. After download, can
@@ -284,27 +311,27 @@ class Catalog(VizTools, Tools):
     @staticmethod
     def _order_payload(
         geometry: Union[
-            Dict,
+            dict,
             Feature,
             FeatureCollection,
-            List,
+            list,
             GeoDataFrame,
             Point,
             Polygon,
         ],
         scene: Series,
-    ) -> Tuple[str, Dict]:
+    ) -> Tuple[str, dict]:
         """
         Helper that constructs necessary parameters for `Order.place` and `Order.estimate`.
 
         Args:
-            geometry (Union[ Dict, Feature, FeatureCollection, List, GeoDataFrame, Point, Polygon, ]): The intended
+            geometry (Union[ dict, Feature, FeatureCollection, list, GeoDataFrame, Point, Polygon, ]): The intended
                 output AOI of the order.
             scene (GeoSeries): A single item/row of the result of `Catalog.search`. For instance, search_results.loc[0]
                 for the first scene of a catalog search result.
 
         Returns:
-            str, Dict: A tuple including a provider name and order parameters.
+            str, dict: A tuple including a provider name and order parameters.
         """
         if not isinstance(scene, Series):
             raise ValueError(
@@ -326,10 +353,10 @@ class Catalog(VizTools, Tools):
     def estimate_order(
         self,
         geometry: Union[
-            Dict,
+            dict,
             Feature,
             FeatureCollection,
-            List,
+            list,
             GeoDataFrame,
             Point,
             Polygon,
@@ -340,7 +367,7 @@ class Catalog(VizTools, Tools):
         Estimate the cost of an order from an item/row in a result of `Catalog.search`.
 
         Args:
-            geometry (Union[ Dict, Feature, FeatureCollection, List, GeoDataFrame, Point, Polygon, ]): The intended
+            geometry (Union[ dict, Feature, FeatureCollection, list, GeoDataFrame, Point, Polygon, ]): The intended
                 output AOI of the order.
             scene (Series): A single item/row of the result of `Catalog.search`. For instance, search_results.loc[0]
                 for the first scene of a catalog search result.
@@ -354,10 +381,10 @@ class Catalog(VizTools, Tools):
     def place_order(
         self,
         geometry: Union[
-            Dict,
+            dict,
             Feature,
             FeatureCollection,
-            List,
+            list,
             GeoDataFrame,
             Point,
             Polygon,
@@ -370,7 +397,7 @@ class Catalog(VizTools, Tools):
         Place an order from an item/row in a result of `Catalog.search`.
 
         Args:
-            geometry (Union[ Dict, Feature, FeatureCollection, List, GeoDataFrame, Point, Polygon, ]): The intended
+            geometry (Union[ dict, Feature, FeatureCollection, list, GeoDataFrame, Point, Polygon, ]): The intended
                 output AOI of the order.
             scene (Series): A single item/row of the result of `Catalog.search`. For instance, search_results.loc[0]
                 for the first scene of a catalog search result.
