@@ -159,7 +159,7 @@ def blocks_from_context():
     class OptionChoiceFromContext(click.Option):
         def full_process_value(self, ctx, value):
             self.type = click.Choice(Tools(ctx.obj).get_blocks().keys())
-            return super().full_process_value(ctx, value)
+            return super().full_process_value(ctx, value)  # pylint: disable=no-member
 
     return OptionChoiceFromContext
 
@@ -274,7 +274,7 @@ def workflows_from_context():
         def full_process_value(self, ctx, value):
             workflow_names = [wkf._info["name"] for wkf in ctx.obj.get_workflows()]
             self.type = click.Choice(workflow_names)
-            return super().full_process_value(ctx, value)
+            return super().full_process_value(ctx, value)  # pylint: disable=no-member
 
     return OptionChoiceFromContext
 
@@ -579,7 +579,7 @@ def get_results_json(job):
 
 @COMMAND_JOB
 @click.pass_obj
-def get_status(job):
+def status(job):
     """
     Get the job status.
     """
@@ -675,7 +675,7 @@ def construct_parameters(
     Follows STAC principles and property names to create a filter for
     catalog search.
     """
-    geometry = catalog.read_vector_file(geom_file)
+    geometry = Tools(catalog.auth).read_vector_file(geom_file)
     start_date_str = start_date.strftime("%Y-%m-%d")
     end_date_str = end_date.strftime("%Y-%m-%d")
     logger.info(
