@@ -1,7 +1,7 @@
 import logging
 from pathlib import Path
 from time import sleep
-from typing import Dict, List, Union, Optional
+from typing import List, Union, Optional
 
 from geopandas import GeoDataFrame
 import requests
@@ -9,10 +9,8 @@ import requests.exceptions
 
 from up42.auth import Auth
 from up42.jobtask import JobTask
-from up42.tools import Tools
 from up42.viztools import VizTools
 from up42.utils import (
-    deprecation,
     get_logger,
     download_results_from_gcs,
     download_results_from_gcs_without_unpacking,
@@ -22,7 +20,7 @@ logger = get_logger(__name__)
 
 
 # pylint: disable=duplicate-code
-class Job(VizTools, Tools):
+class Job(VizTools):
     """
     The Job class is the result of running a workflow. It lets you download, visualize and
         manipulate the results of the job, and keep track of the status or cancel a job while
@@ -44,7 +42,6 @@ class Job(VizTools, Tools):
         auth: Auth,
         project_id: str,
         job_id: str,
-        order_ids: List[str] = None,
     ):
 
         self.auth = auth
@@ -52,24 +49,19 @@ class Job(VizTools, Tools):
         self.job_id = job_id
         self.quicklooks = None
         self.results = None
-        self.order_ids = order_ids
-        if self.auth.get_info:
-            self._info = self.info
+        self._info = self.info
 
     def __repr__(self):
-        order_ids = (
-            f", order_ids: {self.order_ids}, " if self.order_ids is not None else ""
-        )
         info = self.info
         return (
             f"Job(name: {info['name']}, job_id: {self.job_id}, mode: {info['mode']}, "
             f"status: {info['status']}, startedAt: {info['startedAt']}, "
             f"finishedAt: {info['finishedAt']}, workflow_name: {info['workflowName']}, "
-            f"{order_ids}, input_parameters: {info['inputs']}"
+            f"input_parameters: {info['inputs']}"
         )
 
     @property
-    def info(self) -> Dict:
+    def info(self) -> dict:
         """
         Gets the job metadata information.
         """
@@ -88,14 +80,6 @@ class Job(VizTools, Tools):
         logger.info(f"Job is {status}")
         return status
 
-    @deprecation("get_status", "job.status")
-    def get_status(self) -> str:
-        """
-        `get_status` will be deprecated in release 0.13, use
-        [status attribute](job-reference.md#up42.job.Job.status) instead.
-        """
-        return self.status
-
     @property
     def is_succeeded(self) -> bool:
         """
@@ -169,7 +153,7 @@ class Job(VizTools, Tools):
         self.quicklooks = out_paths  # pylint: disable=attribute-defined-outside-init
         return out_paths
 
-    def get_results_json(self, as_dataframe: bool = False) -> Union[Dict, GeoDataFrame]:
+    def get_results_json(self, as_dataframe: bool = False) -> Union[dict, GeoDataFrame]:
         """
         Gets the Job results data.json.
 
@@ -243,27 +227,22 @@ class Job(VizTools, Tools):
         return out_filepaths
 
     def upload_results_to_bucket(
-        self, gs_client, bucket, folder, extension: str = ".tgz", version: str = "v0"
+        self,
+        gs_client,
+        bucket,
+        folder: str,
+        extension: str = ".tgz",
+        version: str = "v0",
     ) -> None:
         """
         Uploads the results of a job directly to a custom google cloud storage bucket.
         """
         download_url = self._get_download_url()
         r = requests.get(download_url)
-
-        if self.order_ids is not None:
-            blob = bucket.blob(
-                str(Path(version) / Path(folder) / Path(self.order_ids[0] + extension))
-            )
-            logger.info(
-                f"Upload job {self.job_id} results with order_ids to "
-                f"{blob.name} ..."
-            )
-        else:
-            blob = bucket.blob(
-                str(Path(version) / Path(folder) / Path(self.job_id + extension))
-            )
-            logger.info(f"Upload job {self.job_id} results to {blob.name} ...")
+        blob = bucket.blob(
+            str(Path(version) / Path(folder) / Path(self.job_id + extension))
+        )
+        logger.info(f"Upload job {self.job_id} results to {blob.name} ...")
         blob.upload_from_string(
             data=r.content,
             content_type="application/octet-stream",
@@ -273,7 +252,7 @@ class Job(VizTools, Tools):
 
     def get_logs(
         self, as_print: bool = True, as_return: bool = False
-    ) -> Optional[Dict]:
+    ) -> Optional[dict]:
         """
         Convenience function to print or return the logs of all job tasks.
 
@@ -286,7 +265,7 @@ class Job(VizTools, Tools):
         """
         job_logs = {}
 
-        jobtasks: List[Dict] = self.get_jobtasks(return_json=True)  # type: ignore
+        jobtasks: List[dict] = self.get_jobtasks(return_json=True)  # type: ignore
         jobtasks_ids = [task["id"] for task in jobtasks]
 
         logger.info(f"Getting logs for {len(jobtasks_ids)} job tasks: {jobtasks_ids}")
@@ -316,7 +295,7 @@ class Job(VizTools, Tools):
 
     def get_jobtasks(
         self, return_json: bool = False
-    ) -> Union[List["JobTask"], List[Dict]]:
+    ) -> Union[List["JobTask"], List[dict]]:
         """
         Get the individual items of the job as JobTask objects or json.
 
@@ -332,7 +311,7 @@ class Job(VizTools, Tools):
         )
         logger.info(f"Getting job tasks: {self.job_id}")
         response_json = self.auth._request(request_type="GET", url=url)
-        jobtasks_json: List[Dict] = response_json["data"]
+        jobtasks_json: List[dict] = response_json["data"]
 
         if return_json:
             return jobtasks_json
@@ -348,7 +327,7 @@ class Job(VizTools, Tools):
             ]
             return jobtasks
 
-    def get_jobtasks_results_json(self) -> Dict:
+    def get_jobtasks_results_json(self) -> dict:
         """
         Convenience function to get the resulting data.json of all job tasks
         in a dictionary of strings.
@@ -356,7 +335,7 @@ class Job(VizTools, Tools):
         Returns:
             The data.json of alle single job tasks.
         """
-        jobtasks: List[Dict] = self.get_jobtasks(return_json=True)  # type: ignore
+        jobtasks: List[dict] = self.get_jobtasks(return_json=True)  # type: ignore
         jobtasks_ids = [task["id"] for task in jobtasks]
         jobtasks_results_json = {}
         for jobtask_id in jobtasks_ids:
