@@ -7,14 +7,13 @@ from geojson import FeatureCollection
 from up42.auth import Auth
 from up42.job import Job
 from up42.viztools import VizTools
-from up42.tools import Tools
 
-from up42.utils import get_logger, deprecation
+from up42.utils import get_logger
 
 logger = get_logger(__name__)
 
 
-class JobCollection(VizTools, Tools):
+class JobCollection(VizTools):
     """
     The JobCollection class provides facilities for handling and downloading
     multiple jobs results as one object.
@@ -50,21 +49,13 @@ class JobCollection(VizTools, Tools):
             yield job
 
     @property
-    def info(self) -> Dict[str, Dict]:
+    def info(self) -> Dict[str, dict]:
         """
         Gets the metadata information for each job in the jobcollection, dictionary of
             job_id : job_information.
         """
         return self.apply(lambda job: job.info, only_succeeded=False)
 
-    @deprecation("get_jobs_info", "jobcollection.info")
-    def get_jobs_info(self) -> Dict[str, Dict]:
-        """
-        `get_jobs_info` will be deprecated in release 0.13, use
-        [info attribute](jobcollection-reference.md#up42.jobcollection.JobCollection.info) instead.
-        """
-        return self.info
-
     @property
     def status(self) -> Dict[str, str]:
         """
@@ -73,14 +64,6 @@ class JobCollection(VizTools, Tools):
         """
         return self.apply(lambda job: job.status, only_succeeded=False)
 
-    @deprecation("get_jobs_status", "jobcollection.status")
-    def get_jobs_status(self) -> Dict[str, str]:
-        """
-        `get_jobs_status` will be deprecated in release 0.13, use
-        [status attribute](jobcollection-reference.md#up42.jobcollection.JobCollection.status) instead.
-        """
-        return self.status
-
     def apply(
         self, worker: Callable, only_succeeded: bool = True, **kwargs
     ) -> Dict[str, Any]:
