@@ -1,11 +1,10 @@
 from pathlib import Path
-from typing import Dict, Union, List
+from typing import Union, List
 
 from geopandas import GeoDataFrame
 from tqdm import tqdm
 
 from up42.auth import Auth
-from up42.tools import Tools
 from up42.viztools import VizTools
 from up42.utils import get_logger, download_results_from_gcs
 
@@ -13,7 +12,7 @@ logger = get_logger(__name__)
 
 
 # pylint: disable=duplicate-code
-class JobTask(VizTools, Tools):
+class JobTask(VizTools):
     """
     The JobTask class provides access to the result of a specific block in the workflow.
     Each job contains one or multiple JobTasks, one for each block.
@@ -38,8 +37,7 @@ class JobTask(VizTools, Tools):
         self.jobtask_id = jobtask_id
         self.quicklooks = None
         self.results = None
-        if self.auth.get_info:
-            self._info = self.info
+        self._info = self.info
 
     def __repr__(self):
         info = self.info[0]
@@ -51,7 +49,7 @@ class JobTask(VizTools, Tools):
         )
 
     @property
-    def info(self) -> Dict:
+    def info(self) -> dict:
         """
         Gets the jobtask metadata information.
         """
@@ -63,7 +61,7 @@ class JobTask(VizTools, Tools):
         self._info = response_json["data"]
         return response_json["data"]
 
-    def get_results_json(self, as_dataframe: bool = False) -> Union[Dict, GeoDataFrame]:
+    def get_results_json(self, as_dataframe: bool = False) -> Union[dict, GeoDataFrame]:
         """
         Gets the Jobtask results data.json.
 
