@@ -1,5 +1,5 @@
 import logging
-from typing import Dict, List, Union
+from typing import Dict, List, Union, Optional
 
 from tqdm import tqdm
 
@@ -8,12 +8,11 @@ from up42.job import Job
 from up42.jobcollection import JobCollection
 from up42.utils import get_logger, filter_jobs_on_mode
 from up42.workflow import Workflow
-from up42.tools import Tools
 
 logger = get_logger(__name__)
 
 
-class Project(Tools):
+class Project:
     """
     The Project is the top-level class of the UP42 hierarchy. With it you can create
     new workflows, query already existing workflows & jobs in the project and manage
@@ -32,8 +31,7 @@ class Project(Tools):
     def __init__(self, auth: Auth, project_id: str):
         self.auth = auth
         self.project_id = project_id
-        if self.auth.get_info:
-            self._info = self.info
+        self._info = self.info
 
     def __repr__(self):
         info = self.info
@@ -45,7 +43,7 @@ class Project(Tools):
         )
 
     @property
-    def info(self) -> Dict:
+    def info(self) -> dict:
         """
         Gets the project metadata information.
         """
@@ -98,7 +96,7 @@ class Project(Tools):
         )
         return workflow
 
-    def get_workflows(self, return_json: bool = False) -> Union[List["Workflow"], Dict]:
+    def get_workflows(self, return_json: bool = False) -> Union[List["Workflow"], dict]:
         """
         Gets all workflows in a project as workflow objects or json.
 
@@ -126,7 +124,7 @@ class Project(Tools):
 
     def get_jobs(
         self, return_json: bool = False, test_jobs: bool = True, real_jobs: bool = True
-    ) -> Union[JobCollection, List[Dict]]:
+    ) -> Union[JobCollection, List[dict]]:
         """
         Get all jobs in the project as a JobCollection or json.
 
@@ -180,9 +178,9 @@ class Project(Tools):
 
     def update_project_settings(
         self,
-        max_aoi_size: int = None,
-        max_concurrent_jobs: int = None,
-        number_of_images=None,
+        max_aoi_size: Optional[int] = None,
+        max_concurrent_jobs: Optional[int] = None,
+        number_of_images: Optional[int] = None,
     ) -> None:
         """
         Updates a project's settings.
@@ -192,20 +190,23 @@ class Project(Tools):
             max_concurrent_jobs: The maximum number of concurrent jobs, from 1-10, default 1.
             number_of_images: The maximum number of images returned with each job, from 1-20, default 10.
         """
+        # The ranges and default values of the project settings can potentially get
+        # increased, so need to be dynamically queried from the server.
+        current_settings = {d["name"]: d for d in self.get_project_settings()}
+
         url = f"{self.auth._endpoint()}/projects/{self.project_id}/settings"
-        payload = [
-            {
-                "name": "JOB_QUERY_MAX_AOI_SIZE",
-                "value": f"{100 if max_aoi_size is None else max_aoi_size}",
-            },
-            {
-                "name": "MAX_CONCURRENT_JOBS",
-                "value": f"{10 if max_concurrent_jobs is None else max_concurrent_jobs}",
-            },
-            {
-                "name": "JOB_QUERY_LIMIT_PARAMETER_MAX_VALUE",
-                "value": f"{10 if number_of_images is None else number_of_images}",
-            },
-        ]
-        self.auth._request(request_type="PUT", url=url, data=payload)
+        payload: Dict = {"settings": {}}
+        desired_settings = {
+            "JOB_QUERY_MAX_AOI_SIZE": max_aoi_size,
+            "MAX_CONCURRENT_JOBS": max_concurrent_jobs,
+            "JOB_QUERY_LIMIT_PARAMETER_MAX_VALUE": number_of_images,
+        }
+
+        for name, desired_setting in desired_settings.items():
+            if desired_setting is None:
+                payload["settings"][name] = str(current_settings[name]["value"])
+            else:
+                payload["settings"][name] = str(desired_setting)
+
+        self.auth._request(request_type="POST", url=url, data=payload)
         logger.info(f"Updated project settings: {payload}")
