@@ -1,4 +1,4 @@
-from typing import Dict, List, Union
+from typing import List, Union
 
 from tqdm import tqdm
 
@@ -6,12 +6,11 @@ from up42.auth import Auth
 from up42.order import Order
 from up42.asset import Asset
 from up42.utils import get_logger
-from up42.tools import Tools
 
 logger = get_logger(__name__)
 
 
-class Storage(Tools):
+class Storage:
     """
     The Storage class enables access to the UP42 storage. You can list
     your assets and orders within an UP42 workspace.
@@ -30,7 +29,7 @@ class Storage(Tools):
         env = ", env: dev" if self.auth.env == "dev" else ""
         return f"Storage(workspace_id: {self.workspace_id}{env})"
 
-    def _paginate(self, url: str) -> List[Dict]:
+    def _paginate(self, url: str) -> List[dict]:
         """
         Helper to fetch list of items in paginated endpoint.
 
@@ -38,7 +37,7 @@ class Storage(Tools):
             url (str): The base paginated endpoint.
 
         Returns:
-            List[Dict]: List of all paginated items.
+            List[dict]: List of all paginated items.
         """
         first_pagination_response = self.auth._request(request_type="GET", url=url)
         output = first_pagination_response["data"]["content"]
@@ -52,7 +51,7 @@ class Storage(Tools):
         assert len(output) == total_items, "Some paginated items are missing!"
         return output
 
-    def get_assets(self, return_json: bool = False) -> Union[List[Asset], Dict]:
+    def get_assets(self, return_json: bool = False) -> Union[List[Asset], dict]:
         """
         Gets all assets in the workspace as Asset objects or json.
 
@@ -74,7 +73,7 @@ class Storage(Tools):
             ]
             return assets
 
-    def get_orders(self, return_json: bool = False) -> Union[List[Order], Dict]:
+    def get_orders(self, return_json: bool = False) -> Union[List[Order], dict]:
         """
         Gets all orders in the workspace as Order objects or json.
 
