@@ -1,11 +1,11 @@
 """
-Base functionality that is not bound to a specific higher level UP42 object.
+Base functionality that is made available on the up42 import object (in the init) and
+not bound to a specific higher level UP42 object.
 """
 
 import json
 from pathlib import Path
-from typing import List, Union, Dict
-import warnings
+from typing import List, Union, Dict, Optional
 
 from geopandas import GeoDataFrame
 import geopandas as gpd
@@ -40,30 +40,10 @@ class Tools:
         self.quicklooks = None
         self.results = None
 
-    def _deprecate_tools(self, function_name: str):
-        # TODO: When finally deprecating this, move the functions that don't require
-        # TODO: the class out of it and import directly in init. Don't need to be
-        # TODO: instatiated via Tools in __init__.
-
-        object_name = self.__class__.__name__
-        if object_name in [
-            "Project",
-            "Workflow",
-            "Job",
-            "JobTask",
-            "JobCollection",
-            "Catalog",
-        ]:
-            message = (
-                f"Use of {object_name}.{function_name} will be deprecated in "
-                f"version 0.14.0, use up42.{function_name} instead!"
-            )
-            warnings.warn(message, DeprecationWarning, stacklevel=3)
-
     # pylint: disable=no-self-use
     def read_vector_file(
         self, filename: str = "aoi.geojson", as_dataframe: bool = False
-    ) -> Union[Dict, GeoDataFrame]:
+    ) -> Union[dict, GeoDataFrame]:
         """
         Reads vector files (geojson, shapefile, kml, wkt) to a feature collection,
         for use as the aoi geometry in the workflow input parameters
@@ -78,8 +58,6 @@ class Tools:
         Returns:
             Feature Collection
         """
-        self._deprecate_tools("read_vector_file")
-
         suffix = Path(filename).suffix
 
         if suffix == ".kml":
@@ -117,8 +95,6 @@ class Tools:
         Returns:
             Feature collection json with the selected aoi.
         """
-        self._deprecate_tools("get_example_aoi")
-
         logger.info(f"Getting small example aoi in location '{location}'.")
         if location == "Berlin":
             example_aoi = self.read_vector_file(
@@ -148,7 +124,6 @@ class Tools:
         Export the drawn aoi via the export button, then read the geometries via
         read_aoi_file().
         """
-        self._deprecate_tools("draw_aoi")
         m = folium_base_map(layer_control=True)
         DrawFoliumOverride(
             export=True,
@@ -168,10 +143,10 @@ class Tools:
 
     def get_blocks(
         self,
-        block_type=None,
+        block_type: Optional[str] = None,
         basic: bool = True,
         as_dataframe=False,
-    ) -> Union[List[Dict], Dict]:
+    ) -> Union[List[Dict], dict]:
         """
         Gets a list of all public blocks on the marketplace.
 
@@ -184,10 +159,8 @@ class Tools:
             A list of the public blocks and their metadata. Optional a simpler version
             dict.
         """
-        self._deprecate_tools("get_blocks")
-
         try:
-            block_type = block_type.lower()
+            block_type = block_type.lower()  # type: ignore
         except AttributeError:
             pass
         if not hasattr(self, "auth"):
@@ -227,7 +200,7 @@ class Tools:
             else:
                 return blocks_json
 
-    def get_block_details(self, block_id: str, as_dataframe=False) -> Dict:
+    def get_block_details(self, block_id: str, as_dataframe: bool = False) -> dict:
         """
         Gets the detailed information about a specific public block from
         the server, includes all manifest.json and marketplace.json contents.
@@ -239,8 +212,6 @@ class Tools:
         Returns:
             A dict of the block details metadata for the specific block.
         """
-        self._deprecate_tools("get_block_details")
-
         if not hasattr(self, "auth"):
             raise Exception(
                 "Requires authentication with UP42, use up42.authenticate()!"
@@ -254,7 +225,7 @@ class Tools:
         else:
             return details_json
 
-    def validate_manifest(self, path_or_json: Union[str, Path, Dict]) -> Dict:
+    def validate_manifest(self, path_or_json: Union[str, Path, dict]) -> dict:
         """
         Validates a block manifest json.
 
@@ -269,8 +240,6 @@ class Tools:
         Returns:
             A dictionary with the validation results and potential validation errors.
         """
-        self._deprecate_tools("validate_manifest")
-
         if isinstance(path_or_json, (str, Path)):
             with open(path_or_json) as src:
                 manifest_json = json.load(src)
