@@ -3,7 +3,9 @@ import logging
 import copy
 from collections import Counter
 from pathlib import Path
-from typing import Dict, List, Union, Tuple
+from typing import Dict, List, Union, Tuple, Optional
+import warnings
+from datetime import datetime
 
 from geopandas import GeoDataFrame
 from shapely.geometry import Point, Polygon
@@ -22,12 +24,13 @@ from up42.utils import (
     any_vector_to_fc,
     fc_to_query_geometry,
     filter_jobs_on_mode,
+    format_time_period,
 )
 
 logger = get_logger(__name__)
 
 
-class Workflow(Tools):
+class Workflow:
     """
     The Workflow class lets you configure & run jobs and query existing jobs related
     to this workflow.
@@ -47,8 +50,7 @@ class Workflow(Tools):
         self.auth = auth
         self.project_id = project_id
         self.workflow_id = workflow_id
-        if self.auth.get_info:
-            self._info = self.info
+        self._info = self.info
 
     def __repr__(self):
         info = self.info
@@ -59,7 +61,7 @@ class Workflow(Tools):
         )
 
     @property
-    def info(self) -> Dict:
+    def info(self) -> dict:
         """
         Gets the workflow metadata information.
         """
@@ -74,14 +76,14 @@ class Workflow(Tools):
     @property
     def workflow_tasks(self) -> Dict[str, str]:
         """
-        Gets the building blocks of the workflow as a dictionary with `task_name:block-version`
+        Gets the building blocks of the workflow as a dictionary with `task_name:block-version`.
         """
         logging.getLogger("up42.workflow").setLevel(logging.CRITICAL)
         workflow_tasks = self.get_workflow_tasks(basic=True)
         logging.getLogger("up42.workflow").setLevel(logging.INFO)
         return workflow_tasks  # type: ignore
 
-    def get_compatible_blocks(self) -> Dict:
+    def get_compatible_blocks(self) -> dict:
         """
         Gets all compatible blocks for the current workflow. If the workflow is empty
         it will provide all data blocks, if the workflow already has workflow tasks, it
@@ -89,7 +91,18 @@ class Workflow(Tools):
 
         Currently no data blocks can be attached to other data blocks.
         """
-        last_task = list(self.get_workflow_tasks(basic=True).keys())[-1]  # type: ignore
+        tasks: dict = self.get_workflow_tasks(basic=True)  # type: ignore
+        if not tasks:
+            logger.info("The workflow is empty, returning all data blocks.")
+
+            logging.getLogger("up42.tools").setLevel(logging.CRITICAL)
+            data_blocks = Tools(auth=self.auth).get_blocks(
+                block_type="data", basic=True
+            )
+            logging.getLogger("up42.tools").setLevel(logging.INFO)
+            return data_blocks  # type: ignore
+
+        last_task = list(tasks.keys())[-1]
         url = (
             f"{self.auth._endpoint()}/projects/{self.project_id}/workflows/{self.workflow_id}/"
             f"compatible-blocks?parentTaskName={last_task}"
@@ -101,9 +114,9 @@ class Workflow(Tools):
         }
         return compatible_blocks
 
-    def get_workflow_tasks(self, basic: bool = False) -> Union[List, Dict]:
+    def get_workflow_tasks(self, basic: bool = False) -> Union[List, dict]:
         """
-        Get the workflow-tasks of the workflow (Blocks in a workflow are called workflow_tasks)
+        Get the workflow-tasks of the workflow (Blocks in a workflow are called workflow_tasks).
 
         Args:
             basic: If selected returns a simplified task-name : block-version dict.
@@ -127,7 +140,7 @@ class Workflow(Tools):
 
     def _construct_full_workflow_tasks_dict(
         self, input_tasks: Union[List]
-    ) -> List[Dict]:
+    ) -> List[dict]:
         """
         Constructs the full workflow task definition from a simplified version.
         Accepts blocks ids, block names, block display names & combinations of them.
@@ -158,7 +171,7 @@ class Workflow(Tools):
 
         # Get public + custom blocks.
         logging.getLogger("up42.tools").setLevel(logging.CRITICAL)
-        blocks: Dict = self.get_blocks(basic=False)  # type: ignore
+        blocks: dict = Tools(auth=self.auth).get_blocks(basic=False)  # type: ignore
         logging.getLogger("up42.tools").setLevel(logging.INFO)
 
         # Get ids of the input tasks, regardless of the specified format.
@@ -208,7 +221,7 @@ class Workflow(Tools):
             previous_task_name = next_task["name"]
         return full_input_tasks_definition
 
-    def add_workflow_tasks(self, input_tasks: Union[List[str], List[Dict]]) -> None:
+    def add_workflow_tasks(self, input_tasks: Union[List[str], List[dict]]) -> None:
         # pylint: disable=line-too-long
         """
         Adds or overwrites workflow tasks in a workflow on UP42.
@@ -267,7 +280,7 @@ class Workflow(Tools):
         self.auth._request(request_type="POST", url=url, data=input_tasks)
         logger.info(f"Added tasks to workflow: {input_tasks}")
 
-    def get_parameters_info(self) -> Dict:
+    def get_parameters_info(self) -> dict:
         """
         Gets infos about the workflow parameters of each block in the current workflow
         to make it easy to construct the desired parameters.
@@ -283,7 +296,7 @@ class Workflow(Tools):
             workflow_parameters_info[task_name] = task_default_parameters
         return workflow_parameters_info
 
-    def _get_default_parameters(self) -> Dict:
+    def _get_default_parameters(self) -> dict:
         """
         Gets the default parameters for the workflow that can be directly used to
         run a job. Excludes geometry operation and geometry of the data block.
@@ -309,24 +322,23 @@ class Workflow(Tools):
     def construct_parameters(
         self,
         geometry: Union[
-            Dict,
+            dict,
             Feature,
             FeatureCollection,
             geojson_Polygon,
-            List,
+            list,
             GeoDataFrame,
             Polygon,
             Point,
         ] = None,
-        geometry_operation: str = None,
+        geometry_operation: Optional[str] = None,
         handle_multiple_features: str = "union",
-        start_date: str = None,
-        end_date: str = None,
-        limit: int = None,
-        scene_ids: List = None,
-        order_ids: List[str] = None,
-        assets: List[Asset] = None,
-    ) -> Dict:
+        start_date: Optional[Union[str, datetime]] = None,
+        end_date: Optional[Union[str, datetime]] = None,
+        limit: Optional[int] = None,
+        scene_ids: Optional[list] = None,
+        assets: Optional[List[Asset]] = None,
+    ) -> dict:
         """
         Constructs workflow input parameters with a specified aoi, the default input parameters, and
         optionally limit and order-ids. Further parameter editing needs to be done manually
@@ -338,28 +350,31 @@ class Workflow(Tools):
                 assume EPSG 4326.
             geometry_operation: Desired operation, One of "bbox", "intersects", "contains".
             limit: Maximum number of expected results.
-            start_date: Query period starting day, format "2020-01-01".
-            end_date: Query period ending day, format "2020-01-01".
+            start_date: Query period starting day as iso-format string or datetime object,
+                e.g. "YYYY-MM-DD" or "YYYY-MM-DDTHH:MM:SS".
+            end_date: Query period ending day as iso-format or datetime object,
+                e.g. "YYYY-MM-DD" or "YYYY-MM-DDTHH:MM:SS".
             scene_ids: List of scene_ids, if given ignores all other parameters except geometry.
-            order_ids: Optional, can be used to incorporate existing bought imagery on UP42
-                into new workflows.
-            assets: Optional, can be used to incorporate existing assets in Storage (result of Orders for instance)
-                into new workflows.
+            assets: Optional, can be used to incorporate existing assets in Storage (result
+                of Orders for instance) into new workflows.
 
         Returns:
             Dictionary of constructed input parameters.
         """
+        message = (
+            "The use of `handle_multiple_features` will be deprecated in version 0.18.0, "
+            "to guarantee feature parity with the UP42 platform. The UP42 SDK from then on "
+            "will only handle single geometries!"
+        )
+        warnings.warn(message, DeprecationWarning, stacklevel=2)
+
         input_parameters = self._get_default_parameters()
         try:
             data_block_name = list(input_parameters.keys())[0]
         except IndexError as e:
             raise ValueError("The Workflow has no workflow tasks.") from e
 
-        if order_ids is not None:
-            # Needs to be handled in this function(not run_job) as it is only
-            # relevant for the data block.
-            input_parameters[data_block_name] = {"order_ids": order_ids}
-        elif assets is not None:
+        if assets is not None:
             # Needs to be handled in this function(not run_job) as it is only
             # relevant for the data block.
             asset_ids = [asset.asset_id for asset in assets if asset.source == "BLOCK"]
@@ -378,9 +393,11 @@ class Workflow(Tools):
                 input_parameters[data_block_name]["ids"] = scene_ids
                 input_parameters[data_block_name]["limit"] = len(scene_ids)
                 input_parameters[data_block_name].pop("time")
-            elif start_date is not None and end_date is not None:
-                time = f"{start_date}T00:00:00Z/{end_date}T23:59:59Z"
-                input_parameters[data_block_name]["time"] = time
+            elif start_date is not None or end_date is not None:
+                time_period = format_time_period(
+                    start_date=start_date, end_date=end_date
+                )
+                input_parameters[data_block_name]["time"] = time_period
 
             if geometry is not None:
                 aoi_fc = any_vector_to_fc(
@@ -399,7 +416,7 @@ class Workflow(Tools):
         self,
         geometries: List[
             Union[
-                Dict,
+                dict,
                 Feature,
                 geojson_Polygon,
                 Polygon,
@@ -407,7 +424,7 @@ class Workflow(Tools):
             ]
         ] = None,
         interval_dates: List[Tuple[str, str]] = None,
-        scene_ids: List = None,
+        scene_ids: List[str] = None,
         limit_per_job: int = 1,
         geometry_operation: str = "intersects",
     ) -> List[dict]:
@@ -471,7 +488,7 @@ class Workflow(Tools):
 
         return result_params
 
-    def estimate_job(self, input_parameters: Union[Dict, str, Path] = None) -> Dict:
+    def estimate_job(self, input_parameters: Union[dict, str, Path] = None) -> dict:
         """
         Estimation of price and duration of the workflow for the provided input parameters.
 
@@ -560,7 +577,7 @@ class Workflow(Tools):
             f"workflows/{self.workflow_id}/jobs?name={name}"
         )
         response_json = self.auth._request(
-            request_type="POST", url=url, data=input_parameters
+            request_type="POST", url=url, data=input_parameters  # type: ignore
         )
         job_json = response_json["data"]
         logger.info(f"Created and running new job: {job_json['id']}.")
@@ -576,7 +593,7 @@ class Workflow(Tools):
 
     def _helper_run_parallel_jobs(
         self,
-        input_parameters_list: List[Dict] = None,
+        input_parameters_list: List[dict] = None,
         max_concurrent_jobs: int = 10,
         test_job: bool = False,
         name: str = None,
@@ -704,7 +721,7 @@ class Workflow(Tools):
 
     def test_jobs_parallel(
         self,
-        input_parameters_list: List[Dict] = None,
+        input_parameters_list: List[dict] = None,
         name: str = None,
         max_concurrent_jobs: int = 10,
     ) -> "JobCollection":
@@ -755,7 +772,7 @@ class Workflow(Tools):
 
     def run_jobs_parallel(
         self,
-        input_parameters_list: List[Dict] = None,
+        input_parameters_list: Optional[List[dict]] = None,
         name: str = None,
         max_concurrent_jobs: int = 10,
     ) -> "JobCollection":
@@ -818,7 +835,9 @@ class Workflow(Tools):
             )
             return jobcollection
 
-    def update_name(self, name: str = None, description: str = None) -> None:
+    def update_name(
+        self, name: Optional[str] = None, description: Optional[str] = None
+    ) -> None:
         """
         Updates the workflow name and description.
 
